# AddDocumentTabRequest

Adds a document tab. When a tab is added at a given index, all subsequent tabs' indexes are incremented.

**Type:** object

## Properties

- **tabProperties** ([TabProperties](tabproperties.md)): The properties of the tab to add. All properties are optional.
